==> dt2801-0.5.tar.gz: dt2801-0.5/dac.h <==
/*
 * Device Driver for DataTranslation DT2801
 *
 * Digital-Analog-Converter subsystem
 *
 */

#ifndef _DT2801_DAC_H
#define _DT2801_DAC_H 1
#ifdef __KERNEL__

/* There are 2 DAC-channels (12-bit reslution), which can be
   configured separately. Either unipolar output (0..5V /
   0..10V full-scale), or bipolar output (-2.5..+2.5V / -5.0..+5.0 /
   -10.0..+10.0).
   This is done with jumpers, so not configurable at runtime. */

#define DT2801_DAC_UNIPOLAR 0
#define DT2801_DAC_BIPOLAR  1

#define DT2801_DAC_BITS 12

#define DT2801_NDACS 2

typedef struct {
        int bits;
        int fullscale;
	int polarity;
	int usecount;
} DAC_t;

typedef struct {
	int conv;
	int dacnr;
        DAC_t dacs[DT2801_NDACS];
} DAC_state;

typedef struct {
	int mode;
	int dacnr;
	int exttrigger;
} DACP;



/* Minor device numbers */
#define DT2801_DAC0     0x00
#define DT2801_DAC1     0x01
#define DT2801_DAC2     0x02

extern struct file_operations dt2801_dac_fops;
extern int dt2801_dac_init(void);
extern int dt2801_dac_cleanup(void);
extern int dt2801_dac_reset(void);
extern int dt2801_dac_open(struct inode *inode, struct file *filp);

#endif /* __KERNEL__ */

typedef struct {
	unsigned int conv;
} Dt2801_DACP_t;


#define DT2801_DAC_IMMEDIATE 1
#define DT2801_DAC_BLOCK     2

#define DT2801_IOCTL_DAC_SET_PARAMS _IOW(DT2801_MAGIC, 0x21, Dt2801_DACP_t*)
#define DT2801_IOCTL_DAC_GET_POLARITY  _IOR(DT2801_MAGIC, 0x22, int)
#define DT2801_IOCTL_DAC_GET_FULLSCALE  _IOR(DT2801_MAGIC, 0x23, int)
#define DT2801_IOCTL_DAC_SET_MODE  _IOW(DT2801_MAGIC, 0x24, int)

#endif /* _DT2801_DAC_H */

==> dt2801-0.6.tar.gz: dt2801-0.6/dac.h <==
/*
 * Device Driver for DataTranslation DT2801
 *
 * Digital-Analog-Converter subsystem
 *
 */

#ifndef _DT2801_DAC_H
#define _DT2801_DAC_H 1
#ifdef __KERNEL__

/* There are 2 DAC-channels (12-bit reslution), which can be
   configured separately. Either unipolar output (0..5V /
   0..10V full-scale), or bipolar output (-2.5..+2.5V / -5.0..+5.0 /
   -10.0..+10.0).
   This is done with jumpers, so not configurable at runtime. */

#define DT2801_DAC_UNIPOLAR 0
#define DT2801_DAC_BIPOLAR  1


/* All Dt2801-series boards have two DACs */
#define DT2801_NDACS 2

typedef struct {
        int bits;
        int fullscale;
	int polarity;
	int usecount;
} DAC_t;

typedef struct {
	int conv;
	int dacnr;
        DAC_t dacs[DT2801_NDACS];
} DAC_state;

typedef struct {
        Dt2801_t* board;

	int mode;
	int dacnr;
	int exttrigger;
} DACP;



/* Minor device numbers */
#define DT2801_DAC0     0x00
#define DT2801_DAC1     0x01
#define DT2801_DAC2     0x02

extern struct file_operations dt2801_dac_fops;
extern int dt2801_dac_init(Dt2801_t*);
extern void dt2801_dac_info(Dt2801_t*);
extern int dt2801_dac_cleanup(Dt2801_t*);
extern int dt2801_dac_reset(Dt2801_t*);
extern int dt2801_dac_open(struct inode *inode, struct file *filp);

#endif /* __KERNEL__ */

typedef struct {
	unsigned int conv;
} Dt2801_DACP_t;


#define DT2801_DAC_IMMEDIATE 1
#define DT2801_DAC_BLOCK     2

#define DT2801_IOCTL_DAC_SET_PARAMS _IOW(DT2801_MAGIC, 0x21, Dt2801_DACP_t*)
#define DT2801_IOCTL_DAC_GET_POLARITY  _IOR(DT2801_MAGIC, 0x22, int)
#define DT2801_IOCTL_DAC_GET_FULLSCALE  _IOR(DT2801_MAGIC, 0x23, int)
#define DT2801_IOCTL_DAC_SET_MODE  _IOW(DT2801_MAGIC, 0x24, int)

#endif /* _DT2801_DAC_H */
